@@ -11,8 +11,8 @@ from pydantic_settings import (
 from archipy.configs.config_template import (
     AuthConfig,
     DatetimeConfig,
-    ElasticSearchAPMConfig,
-    ElasticSearchConfig,
+    ElasticsearchAPMConfig,
+    ElasticsearchConfig,
     EmailConfig,
     FastAPIConfig,
     FileConfig,
@@ -21,10 +21,14 @@ from archipy.configs.config_template import (
     KavenegarConfig,
     KeycloakConfig,
     MinioConfig,
+    ParsianShaparakConfig,
+    PostgresSQLAlchemyConfig,
     PrometheusConfig,
     RedisConfig,
     SentryConfig,
-    SqlAlchemyConfig,
+    SQLAlchemyConfig,
+    SQLiteSQLAlchemyConfig,
+    StarRocksSQLAlchemyConfig,
 )
 from archipy.configs.environment_type import EnvironmentType
 
@@ -58,12 +62,25 @@ class BaseConfig(BaseSettings, Generic[R]):
     Attributes:
         AUTH (AuthConfig): Authentication and security settings
         DATETIME (DatetimeConfig): Date/time handling configuration
-        ELASTIC (ElasticSearchConfig): Elasticsearch configuration
+        ELASTIC (ElasticsearchConfig): Elasticsearch configuration
+        ELASTIC_APM (ElasticsearchAPMConfig): Elasticsearch APM configuration
         EMAIL (EmailConfig): Email service configuration
         ENVIRONMENT (EnvironmentType): Application environment (dev, test, prod)
         FASTAPI (FastAPIConfig): FastAPI framework settings
+        FILE (FileConfig): File handling configuration
+        GRPC (GrpcConfig): gRPC service configuration
+        KAFKA (KafkaConfig): Kafka integration configuration
+        KAVENEGAR (KavenegarConfig): Kavenegar SMS service configuration
+        KEYCLOAK (KeycloakConfig): Keycloak integration configuration
+        MINIO (MinioConfig): MinIO object storage configuration
+        PARSIAN_SHAPARAK (ParsianShaparakConfig): Parsian Shaparak payment gateway configuration
+        POSTGRES_SQLALCHEMY (PostgresSQLAlchemyConfig): PostgreSQL SQLAlchemy configuration
+        PROMETHEUS (PrometheusConfig): Prometheus metrics configuration
         REDIS (RedisConfig): Redis cache configuration
-        SQLALCHEMY (SqlAlchemyConfig): Database ORM configuration
+        SENTRY (SentryConfig): Sentry error tracking configuration
+        SQLALCHEMY (SQLAlchemyConfig): Database ORM configuration
+        SQLITE_SQLALCHEMY (SqliteSQLAlchemyConfig): SQLite SQLAlchemy configuration
+        STARROCKS_SQLALCHEMY (StarrocksSQLAlchemyConfig): Starrocks SQLAlchemy configuration
 
     Examples:
         >>> from archipy.configs.base_config import BaseConfig
@@ -135,8 +152,8 @@ class BaseConfig(BaseSettings, Generic[R]):
 
     AUTH: AuthConfig = AuthConfig()
     DATETIME: DatetimeConfig = DatetimeConfig()
-    ELASTIC: ElasticSearchConfig = ElasticSearchConfig()
-    ELASTIC_APM: ElasticSearchAPMConfig = ElasticSearchAPMConfig()
+    ELASTIC: ElasticsearchConfig = ElasticsearchConfig()
+    ELASTIC_APM: ElasticsearchAPMConfig = ElasticsearchAPMConfig()
     EMAIL: EmailConfig = EmailConfig()
     ENVIRONMENT: EnvironmentType = EnvironmentType.LOCAL
     FASTAPI: FastAPIConfig = FastAPIConfig()
@@ -146,10 +163,14 @@ class BaseConfig(BaseSettings, Generic[R]):
     KAVENEGAR: KavenegarConfig = KavenegarConfig()
     KEYCLOAK: KeycloakConfig = KeycloakConfig()
     MINIO: MinioConfig = MinioConfig()
+    PARSIAN_SHAPARAK: ParsianShaparakConfig = ParsianShaparakConfig()
     PROMETHEUS: PrometheusConfig = PrometheusConfig()
     REDIS: RedisConfig = RedisConfig()
     SENTRY: SentryConfig = SentryConfig()
-    SQLALCHEMY: SqlAlchemyConfig = SqlAlchemyConfig()
+    SQLALCHEMY: SQLAlchemyConfig = SQLAlchemyConfig()
+    STARROCKS_SQLALCHEMY: StarRocksSQLAlchemyConfig = StarRocksSQLAlchemyConfig()
+    POSTGRES_SQLALCHEMY: PostgresSQLAlchemyConfig = PostgresSQLAlchemyConfig()
+    SQLITE_SQLALCHEMY: SQLiteSQLAlchemyConfig = SQLiteSQLAlchemyConfig()
 
     def customize(self) -> None:
         """Customize configuration after loading.
@@ -157,13 +178,14 @@ class BaseConfig(BaseSettings, Generic[R]):
         This method can be overridden in subclasses to perform
         custom configuration modifications after loading settings.
         """
+        self.ELASTIC_APM.ENVIRONMENT = self.ENVIRONMENT
 
     @classmethod
-    def global_config(cls) -> R:
+    def global_config(cls) -> Self:
         """Retrieves the global configuration instance.
 
         Returns:
-            R: The global configuration instance.
+            Self: The global configuration instance.
 
         Raises:
             AssertionError: If the global config hasn't been set with
