@@ -427,3 +427,37 @@ class StringUtils(StringUtilsConstants):
             text = cls.normalize_punctuation_spacing(text)
 
         return text.strip()
+
+    @classmethod
+    def snake_to_camel_case(cls, text: str) -> str:
+        """Converts snake_case to camelCase.
+
+        Args:
+            text (str): The input text in snake_case format.
+
+        Returns:
+            str: The text converted to camelCase format.
+        """
+        if cls.is_string_none_or_empty(text):
+            return text
+
+        components = text.split("_")
+        # First component remains lowercase, the rest get capitalized
+        return components[0] + "".join(x.title() for x in components[1:])
+
+    @classmethod
+    def camel_to_snake_case(cls, text: str) -> str:
+        """Converts camelCase to snake_case.
+
+        Args:
+            text (str): The input text in camelCase format.
+
+        Returns:
+            str: The text converted to snake_case format.
+        """
+        if cls.is_string_none_or_empty(text):
+            return text
+
+        # Add underscore before each capital letter and convert to lowercase
+        s1 = re.sub("(.)([A-Z][a-z]+)", r"\1_\2", text)
+        return re.sub("([a-z0-9])([A-Z])", r"\1_\2", s1).lower()
